| getTickers | R Documentation |
This function fetches detailed ticker information from the Kraken API for specified trading pairs or all available pairs.
getTickers(pairs = "All")
pairs |
A character vector specifying the pairs to retrieve ticker information for. Use "All" to fetch data for all pairs. For specific pairs, provide their abbreviations (e.g., "ADAEUR" or c("ADAEUR", "BTCUSD")). Default is "All". |
A data frame containing detailed ticker information for the requested pairs with renamed and split columns, where applicable, and all numbers treated as numeric.
getTickers()
getTickers("ADAEUR")
getTickers(c("ADAEUR", "BTCUSD"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.